package com.ekexiu.project.storage.diacrisis;

import java.io.ByteArrayOutputStream;
import java.io.File;
import java.io.InputStream;
import java.net.HttpURLConnection;
import java.net.URL;
import java.util.LinkedList;
import java.util.concurrent.TimeUnit;

import org.jfw.util.ConstData;
import org.jfw.util.context.JfwAppContext;
import org.jfw.util.io.IoUtil;
import org.jfw.util.log.LogFactory;
import org.jfw.util.log.Logger;

public class AiDiacrisisTask implements Runnable {

	private static Logger LOG = LogFactory.getLog(AiDiacrisisTask.class);

	private static int processing = 2;
	private String urlPrefix = "http://192.168.3.114:5000/test?pi=";

	private static LinkedList<AiDiacrisisTask> queue = new LinkedList<AiDiacrisisTask>();
	private String taskId;
	private int taskType;
	private AiTaskService aiTaskService;

	public AiDiacrisisTask(String taskId, int taskType, AiTaskService aiTaskService) {
		this.taskId = taskId;
		this.taskType = taskType;
		this.aiTaskService = aiTaskService;
	}

	@Override
	public void run() {
		synchronized (AiDiacrisisTask.class) {
			if (AiDiacrisisTask.processing > 0) {
				AiDiacrisisTask.processing--;
			} else {
				AiDiacrisisTask.queue.add(this);
				return;
			}
		}
		aiTaskService.updateTaskState(taskId, 600, null, null);
		this.doRun();
		synchronized (AiDiacrisisTask.class) {
			AiDiacrisisTask.processing++;
			if (AiDiacrisisTask.queue.size() > 0) {
				AiDiacrisisTask next = AiDiacrisisTask.queue.pollLast();
				JfwAppContext.getScheduledExecutorService().schedule(next, 50, TimeUnit.MILLISECONDS);
			}
		}
	}

	private void doRun() {
		int nextState = 650;
		String nextStateCode = "ERR0599";

		File file = new File(aiTaskService.getDstPath(), taskId);
		if (file.exists() && file.isDirectory()) {
			try {
				URL u = new URL(urlPrefix + file.getAbsolutePath());
				HttpURLConnection httpURLConnection = (HttpURLConnection) u.openConnection();
				if (httpURLConnection.getResponseCode() == 200) {
					InputStream in = httpURLConnection.getInputStream();
					try {
						ByteArrayOutputStream out = new ByteArrayOutputStream();
						byte[] buf = new byte[128];
						int len = 0;
						while ((len = in.read(buf)) != -1) {
							if (len > 0) {
								out.write(buf, 0, len);
							}
						}
						buf = out.toByteArray();
						if (buf.length > 0) {
							String ret = new String(buf, ConstData.UTF8);
							ret = ret.trim();
							if (ret.equals("1")) {
								nextState = 699;
								nextStateCode = null;
							}
						}

					} catch (Exception e) {
					} finally {
						IoUtil.close(in);
					}
				} else {
					nextStateCode = "ERR0502";
				}
			} catch (Exception ee) {
			}

		}
		aiTaskService.updateTaskState(taskId, nextState, nextStateCode, null);
	}
}
